import React from 'react'
import { reduxForm } from 'redux-form'
import { isEmpty } from 'lodash'
import { RadioGroup, ValidatedField, Button } from '@pubsweet/ui'

import { utils } from './'
import { FormItems } from '../UIComponents'

const { Row, Title, RowItem, RootContainer, CustomRadioGroup } = FormItems

const StepOne = ({ hideModal, disabled, onSubmit, reviews }) => (
  <RootContainer>
    <Title>Recommendation for Next Phase</Title>
    <Row>
      <RowItem>
        <ValidatedField
          component={input => (
            <CustomRadioGroup
              className="custom-radio-group"
              justify="space-between"
            >
              <RadioGroup
                name="decision"
                options={
                  !isEmpty(reviews)
                    ? utils.recommendationOptions
                    : utils.recommendationOptions.slice(1)
                }
                {...input}
              />
            </CustomRadioGroup>
          )}
          name="decision"
        />
      </RowItem>
    </Row>
    <Row>
      <RowItem centered>
        <Button onClick={hideModal}>Cancel</Button>
      </RowItem>
      <RowItem centered>
        <Button disabled={disabled} onClick={onSubmit} primary>
          Next
        </Button>
      </RowItem>
    </Row>
  </RootContainer>
)

export default reduxForm({
  form: 'recommendation',
  destroyOnUnmount: false,
  enableReinitialize: false,
  forceUnregisterOnUnmount: true,
})(StepOne)
